==> commons-cli-1.8.0-src.zip: commons-cli-1.8.0-src/src/test/java/org/apache/commons/cli/AlreadySelectedExceptionTest.java <==
/*
  Licensed to the Apache Software Foundation (ASF) under one or more
  contributor license agreements.  See the NOTICE file distributed with
  this work for additional information regarding copyright ownership.
  The ASF licenses this file to You under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with
  the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.apache.commons.cli;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertNull;

import org.junit.jupiter.api.Test;

/**
 * Tests {@link AlreadySelectedException}.
 */
public class AlreadySelectedExceptionTest {

    @Test
    public void testConstructor() {
        assertEquals("a", new AlreadySelectedException("a").getMessage());
        assertNull(new AlreadySelectedException("a").getOption());
        final Option option = new Option("a", "d");
        final OptionGroup group = new OptionGroup();
        assertNotNull(new AlreadySelectedException(group, option).getMessage());
        assertEquals(option, new AlreadySelectedException(group, option).getOption());
        assertEquals(group, new AlreadySelectedException(group, option).getOptionGroup());
    }
}

==> commons-cli-1.11.0-src.zip: commons-cli-1.11.0-src/src/test/java/org/apache/commons/cli/AlreadySelectedExceptionTest.java <==
/*
  Licensed to the Apache Software Foundation (ASF) under one or more
  contributor license agreements.  See the NOTICE file distributed with
  this work for additional information regarding copyright ownership.
  The ASF licenses this file to You under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with
  the License.  You may obtain a copy of the License at

      https://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.apache.commons.cli;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertNull;

import org.junit.jupiter.api.Test;

/**
 * Tests {@link AlreadySelectedException}.
 */
class AlreadySelectedExceptionTest {

    @Test
    void testConstructor() {
        assertEquals("a", new AlreadySelectedException("a").getMessage());
        assertNull(new AlreadySelectedException("a").getOption());
        final Option option = new Option("a", "d");
        final OptionGroup optionGroup = new OptionGroup();
        assertNotNull(new AlreadySelectedException(optionGroup, option).getMessage());
        assertEquals(option, new AlreadySelectedException(optionGroup, option).getOption());
        assertEquals(optionGroup, new AlreadySelectedException(optionGroup, option).getOptionGroup());
    }
}
